@@ -1,6 +1,7 @@
 
 
 # TODO: color lines with ==> using `colorama`
+# TODO: add a step to verify that the genome build is correct using detect_ref (probably after `sites`)
 
 import time
 import importlib
@@ -9,18 +10,17 @@ scripts = '''
 phenolist verify
 parse_input_files
 sites
-make_gene_aliases_trie
+make_gene_aliases_sqlite3
 add_rsids
 add_genes
-make_tries
+make_cpras_rsids_sqlite3
 augment_phenos
-manhattan
-qq
 matrix
-bgzip_phenos
-top_hits
-phenotypes
 gather_pvalues_for_each_gene
+manhattan
+top_hits
+qq
+phenotypes
 pheno_correlation
 '''.split('\n')
 scripts = [script for script in scripts if script]
