@@ -48,15 +48,15 @@ LocusZoom.TransformationFunctions.set("percent", function(x) {
     var remoteBase = "https://portaldev.sph.umich.edu/api/v1/";
     var data_sources = new LocusZoom.DataSources()
         .add("assoc", ["AssociationPheWeb", localBase])
-        .add("catalog", ["GwasCatalogLZ", {url: remoteBase + 'annotation/gwascatalog/results/', params: { source: 2, build: "GRCh37" }}])
+        .add("catalog", ["GwasCatalogLZ", {url: remoteBase + 'annotation/gwascatalog/results/', params: { source: 2, build: "GRCh"+window.model.grch_build_number }}])
         .add("ld", ["LDLZ2", { url: "https://portaldev.sph.umich.edu/ld/",
-            params: { source: '1000G', build: 'GRCh37', population: 'ALL' }
+            params: { source: '1000G', build: 'GRCh'+window.model.grch_build_number, population: 'ALL' }
         }])
-        .add("gene", ["GeneLZ", { url: remoteBase + "annotation/genes/", params: {source: 2} }])
-        .add("recomb", ["RecombLZ", { url: remoteBase + "annotation/recomb/results/", params: {source: 15} }]);
+        .add("gene", ["GeneLZ", { url: remoteBase + "annotation/genes/", params: {build: 'GRCh'+window.model.grch_build_number} }])
+        .add("recomb", ["RecombLZ", { url: remoteBase + "annotation/recomb/results/", params: {build:'GRCh'+window.model.grch_build_number} }]);
 
-    LocusZoom.TransformationFunctions.set("neglog10_or_100", function(x) {
-        if (x === 0) return 100;
+    LocusZoom.TransformationFunctions.set("neglog10_or_323", function(x) {
+        if (x === 0) return 323;
         return -Math.log(x) / Math.LN10;
     });
 
@@ -267,7 +267,7 @@ LocusZoom.TransformationFunctions.set("percent", function(x) {
                                     "{{namespace[assoc]}}all", // special mock value for the custom source
                                     "{{namespace[assoc]}}id",
                                     "{{namespace[assoc]}}position",
-                                    "{{namespace[assoc]}}pvalue|neglog10_or_100",
+                                    "{{namespace[assoc]}}pvalue|neglog10_or_323",
                                     "{{namespace[ld]}}state", "{{namespace[ld]}}isrefvar",
                                     "{{namespace[catalog]}}rsid", "{{namespace[catalog]}}trait", "{{namespace[catalog]}}log_pvalue"
                                 ],
@@ -290,7 +290,7 @@ LocusZoom.TransformationFunctions.set("percent", function(x) {
                                 x_axis: { field: "{{namespace[assoc]}}position" },
                                 y_axis: {
                                     axis: 1,
-                                    field: "{{namespace[assoc]}}pvalue|neglog10_or_100",
+                                    field: "{{namespace[assoc]}}pvalue|neglog10_or_323",
                                     floor: 0,
                                     upper_buffer: 0.1,
                                     min_extent: [0, 10]
@@ -350,6 +350,7 @@ LocusZoom.TransformationFunctions.set("percent", function(x) {
     $(function() {
         // Populate the div with a LocusZoom plot using the default layout
         window.plot = LocusZoom.populate("#lz-1", data_sources, layout);
+        window.plot.state.genome_build = 'GRCh'+window.model.grch_build_number;
 
         // Handle double-click on a variant point
         (function() {
